==> react-head-1.0.2.tgz: package/lib/server.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";

function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }

function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }

import { renderToString } from 'react-dom/server';
import { BODY_ATTRIBUTES_KEY } from './Body';
import { HTML_ATTRIBUTES_KEY } from './Html';
/**
 * Extract props from a list of tags a specific tag by using a key
 * and then discard this key before returning the key
 * @param {Array} tags
 * @param {{ withKey: String }} options
 * @returns {Object}
 */

var extractPropsFrom = function extractPropsFrom(tags, _ref) {
  var withKey = _ref.withKey;

  // search the tag using the key and default to an empty object for simplicity
  var _ref2 = tags.find(function (_ref3) {
    var props = _ref3.props;
    return typeof props[withKey] !== 'undefined';
  }) || {},
      props = _ref2.props;

  if (props) {
    // discard the key used to search the tag
    var unusedKey = props[withKey],
        restOfTag = _objectWithoutProperties(props, [withKey].map(_toPropertyKey)); // return only the desired info for the tag


    return restOfTag;
  }
};
/**
 * Transform the object from the head to a string to be used in the server
 * @param {{ [key: string]: string }} headObject
 * @returns {String}
 */


var transformToString = function transformToString(headObject) {
  if (headObject === void 0) {
    headObject = {};
  }

  return Object.entries(headObject).map(function (_ref4) {
    var _ref5 = _slicedToArray(_ref4, 2),
        key = _ref5[0],
        value = _ref5[1];

    return key + "=\"" + value + "\"";
  }).join(' ');
};
/**
 * Render the tags for the head
 * @param {Array} headTags
 * @returns {{ headString: String, bodyAttributes: String, htmlAttributes: String}}
 */


export function renderHeadTagsToString(headTags) {
  var bodyAttributesProps = extractPropsFrom(headTags, {
    withKey: BODY_ATTRIBUTES_KEY
  });
  var htmlAttributesProps = extractPropsFrom(headTags, {
    withKey: HTML_ATTRIBUTES_KEY
  });
  var headTagsToRender = headTags.filter(function (_ref6) {
    var props = _ref6.props;
    return typeof props[BODY_ATTRIBUTES_KEY] !== 'undefined' || typeof props[HTML_ATTRIBUTES_KEY] !== 'undefined';
  });
  return {
    headString: renderToString(headTagsToRender),
    bodyAttributes: transformToString(bodyAttributesProps),
    htmlAttributes: transformToString(htmlAttributesProps)
  };
}

==> react-head-1.4.0.tgz: package/lib/server.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { renderToString } from 'react-dom/server';
import { BODY_ATTRIBUTES_KEY } from './Body';
import { HTML_ATTRIBUTES_KEY } from './Html';
/**
 * Extract props from a list of tags a specific tag by using a key
 * and then discard this key before returning the key
 * @param {Array} tags
 * @param {{ withKey: String }} options
 * @returns {Object}
 */

var extractPropsFrom = function extractPropsFrom(tags, _ref) {
  var withKey = _ref.withKey;

  // search the tag using the key and default to an empty object for simplicity
  var _ref2 = tags.find(function (_ref3) {
    var props = _ref3.props;
    return props.name === withKey;
  }) || {},
      props = _ref2.props;

  if (props) {
    // discard the key used to search the tag
    var name = props.name,
        restOfTag = _objectWithoutPropertiesLoose(props, ["name"]); // return only the desired info for the tag


    return restOfTag;
  }
};
/**
 * Transform the object from the head to a string to be used in the server
 * @param {{ [key: string]: string }} headObject
 * @returns {String}
 */


var transformToString = function transformToString(headObject) {
  if (headObject === void 0) {
    headObject = {};
  }

  return Object.entries(headObject).map(function (_ref4) {
    var key = _ref4[0],
        value = _ref4[1];
    return key + "=\"" + value + "\"";
  }).join(' ');
};
/**
 * Render the tags for the head
 * @param {Array} headTags
 * @returns {{ headString: String, bodyAttributes: String, htmlAttributes: String}}
 */


export function renderHeadTagsToString(headTags) {
  var bodyAttributesProps = extractPropsFrom(headTags, {
    withKey: BODY_ATTRIBUTES_KEY
  });
  var htmlAttributesProps = extractPropsFrom(headTags, {
    withKey: HTML_ATTRIBUTES_KEY
  });
  var headTagsToRender = headTags.filter(function (_ref5) {
    var props = _ref5.props;
    return props.name !== BODY_ATTRIBUTES_KEY && props.name !== HTML_ATTRIBUTES_KEY;
  });
  return {
    headString: renderToString(headTagsToRender),
    bodyAttributes: transformToString(bodyAttributesProps),
    htmlAttributes: transformToString(htmlAttributesProps)
  };
}
